package com.nto.domain.repository

import com.nto.data.models.LoginResult
import com.nto.data.models.UserDTO
import com.nto.data.repository.DataRepositoryImpl
import java.io.IOException
import javax.inject.Inject

class DomainRepositoryImpl @Inject constructor(private val dataRepositoryImpl: DataRepositoryImpl) :
    DomainRepository {
    override suspend fun auth(email: String, password: String): LoginResult {
        return try {
            dataRepositoryImpl.auth(
                login = email,
                password = password
            )
        } catch (e: IOException) {
            LoginResult(false, "IO exception was thrown: ${e.message}")
        }
    }

    override suspend fun saveToken(token: String) {
        dataRepositoryImpl.saveToken(token)
    }

    override suspend fun getToken(): String {
        return dataRepositoryImpl.getToken()
    }

    override suspend fun getInfo(): UserDTO{
        return dataRepositoryImpl.getInfo()
    }
}