package com.nto.presentation.screens.profileScreen

import android.content.Context
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import androidx.navigation.NavController
import com.nto.data.models.Position
import com.nto.data.utils.Destinations
import com.nto.domain.usecase.ProfileUseCase
import com.nto.presentation.R
import dagger.hilt.android.lifecycle.HiltViewModel
import dagger.hilt.android.qualifiers.ApplicationContext
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ProfileViewModel @Inject constructor(
    private val useCase: ProfileUseCase, @ApplicationContext private val context: Context
) : ViewModel() {
    private val _state = MutableStateFlow(ProfileState())

    val state: StateFlow<ProfileState>
        get() = _state.asStateFlow()

    fun updateInfo() {
        viewModelScope.launch(Dispatchers.IO) {
            val result = useCase.getInfo()
            if (result.isError) return@launch
            _state.tryEmit(ProfileState().apply { deserialize(result, context) })
        }
    }

    fun admin(navController: NavController) {
        //TODO
    }

    fun logout(navController: NavController) {
        //TODO
    }

    fun scan(navController: NavController) {
        navController.navigate(Destinations.Scan)
    }

    fun option(navController: NavController) {
        navController.navigate(Destinations.Options)
    }

    init {
        updateInfo()
    }
}